#
# spec file for package ecore
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ecore
Version:        1.7.4
Release:        12.1
Summary:        Core mainloop, display abstraction and utility library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  SDL-devel
BuildRequires:  doxygen
BuildRequires:  eet-devel >= %version
BuildRequires:  eina-devel >= %version
BuildRequires:  evas-devel >= %version
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel
BuildRequires:  libcurl-devel
BuildRequires:  openssl-devel
BuildRequires:  pixman-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  libX11-devel
BuildRequires:  libX11-devel
BuildRequires:  libXdmcp-devel
BuildRequires:  libXext-devel
BuildRequires:  libxcb-devel
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ecore is a clean and tiny event loop library with many modules to do lots of convenient things for a programmer, to save time and effort.

%package -n libecore1
Summary:        ECore Dynamic Libraries
Group:          System/Libraries
Requires:       %name

%description -n libecore1
Headers, static libraries, test programs and documentation for ecore

%package devel
Summary:        Ecore headers, static libraries, documentation and test programs
Group:          Development/Libraries/C and C++
Requires:       %name = %version
Requires:       eet-devel >= %version
Requires:       eina-devel >= %version
Requires:       evas-devel >= %version
Requires:       pkgconfig(freetype2)
Requires:       glib2-devel
Requires:       libcurl-devel
Requires:       libecore1 = %{version}
Requires:       pixman-devel
Requires:       libX11-devel
Requires:       libXdmcp-devel

%description devel
Headers, static libraries, test programs and documentation for ecore

%package doc-html
Summary:        HTML documentation of Ecore
Group:          Documentation/HTML

%description doc-html
Documentation of Ecore library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Eina
Group:          Documentation/Man

%description doc-man
Documentation of Eina library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules --enable-ecore-sdl --enable-ecore-evas-opengl-sdl
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;
%find_lang %{name}

%clean
%{?buildroot:rm -rf %{buildroot}}

%post -n libecore1 -p /sbin/ldconfig

%postun  -n libecore1 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-, root, root)
%{_libdir}/ecore

%files -n libecore1
%defattr(-, root, root)
%{_libdir}/libecore*.so.1*

%files devel
%defattr(-, root, root)
%{_includedir}/ecore-1/
%{_libdir}/libecore*.so
%{_libdir}/pkgconfig/ecore*.pc

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-12.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Ecore 1.7.3:
  * Fix XCB compile with screensaver support
  * Fix build without IPv6.
  * Fix possible memory corruption in xrandr EDID functions.
  * Backport 81304, which fixes memory errors in
    ecore_evas_extn
  * Fix big rendering/conversion problem in kvm/qemu 24bpp.
* Thu Dec 20 2012 sleep_walker@suse.cz
- package also man pages
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Thu Dec 20 2012 sleep_walker@suse.cz
- enable build of ecore_SDL and software_SDL and OpenGL_SDL support
* Thu Dec 20 2012 sleep_walker@suse.cz
- move localisation and modules into separate package
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Sat Nov 24 2012 sleep_walker@suse.cz
- simplify make install
- clean up spec file
- update to 1.7.2
  - only version number change to be synced with other EFL libraries
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove condition for SLES 10 as we don't build for that anymore
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove condition for CentOS 5 as we don't build for that anymore
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove ecore-fix-xk.patch as it is not needed for current targets
- remove files not belonging to build
* Thu Nov 15 2012 sleep_walker@suse.cz
- try to remove ecore-fix-xk.patch and see results
* Thu Nov 15 2012 sleep_walker@suse.cz
- correct license to SPDX format
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Sat Oct 20 2012 simon@simotek.net
- bump to 1.7.1
* Thu Sep 20 2012 sleep_walker@suse.cz
- change pkgconfig dependency to package name
* Sun Sep  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 425d4455e085c57d6e416f8849e2c6765ad031c7
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file change makeinstall --> make_install
* Fri Sep  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2d65e120a67c1c650d26154ca00ce185c559b2d0
* Fri Sep  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision c8005191519ca769a42448d02752817434ff048b
* Thu Sep  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision c8005191519ca769a42448d02752817434ff048b
* Sat Aug 11 2012 sleep_walker@suse.cz
- alter to 1.7.0-alpha
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 291239f08db1985cd91782d2a34616fd887a0cc1
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 238efbcb7969415fc870af31c6f3605af8ac04df
* Wed Aug  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 33b8db42f5ae0945d3e0b47f29527f744caea26b
* Fri Jul 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2e97827239b9c6baa5378852b74dd517b01a138d
* Thu Jul 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision af314951e50528de415724e486b9c3d6701812b5
* Fri Jul 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision bc4ee4202871ec8dbcacbdedf2e21f783ca99855
* Thu Jul 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fda6dacc3887d37d8a2a3d348f117a038342fb23
* Mon Jul  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5a7534c41fd311fa42d02503fc91f08ee3cd0aa0
* Sat Jul  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2225b1fdf397d43232758d526b562818c4712287
* Fri Jul  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1b5cd52486cf7468f18faabcb34f5881ea77aaaa
* Thu Jul  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cc2d5703613ff55350e23f2c43b536e39339687e
* Mon Jul  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e28b4aa94be5cd3d3c48aa82defa86dfed6fab5d
* Thu Jun 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision c1b8583751b9dabb5505cbc7ddb18d253d250c99
* Wed Jun 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5ffc73886094f54162d2a891d1e9cd9070ae8880
* Sun Jun 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ac20504f2696d21d044f7a968c0e7b762f673987
* Sat Jun 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 377184f152fe31ba71021fe0ec5e1e3cdd68b194
* Fri Jun 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ae1ffde52cd687abcecf7cf3f30cf4daf934c302
* Thu Jun 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 358f9170661b69b68d63128a453deea977a7f5d8
* Tue Jun 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3acde7c666871cb0cdcbdb2dc493100bac678faa
* Mon Jun 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 063a3d3e5bbd39a0e9e48a2dc4e6850fff477bbc
* Sat Jun 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0611ee3975a0857bfbe7663b2fb5403de37ac8ee
* Fri Jun 15 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a8d32f0e26a27b6783289d20fda94f1b3a0d5283
* Thu Jun 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e99456c17c2ad746fe0d6bc608fff73450a9e0dc
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision f74ec34252b860bcde57e08a9386ad1f663e0a92
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6906ac1397b382592df1065b8a8a468b37c37f06
* Fri Jun  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8a150e73705ecbaaba2b3f987676cb1374f0c7c7
* Fri Jun  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e1d09a121e3b7ca9ad80798582816a853b24212f
* Thu Jun  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 94bf2045e6f1ae0e5847e7b487135841f5cc99ae
* Tue Jun  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 917edb77719d2c7774371e5c87980e87447a5c9d
* Mon Jun  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5b01944baa1ac125b58973c9d0667a91cbd4d7ec
* Fri Jun  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision aa3cdf0a5a2bf176ab3f18437513e5af0ffc5552
* Tue May 29 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3c85e4a2d6f7a50f6b67b10a18567229180df063
* Mon May 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fa53b36b128028a9a7fb1abb98a6251c955c85d7
* Fri May 25 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision acbd2d78508c3c644195aecc8acb28c24a686ecf
* Thu May 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 580d9a6dcaa235cbe485b31784fbb370b40b0755
* Mon May 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 31230779ef97925c8ba2992705d2f0dcc575c089
* Fri May 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 987be7481440053832c51e4507d3f891eab9992a
* Mon May 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 01c54859cc1ff6b56a89385c74bd88012d2234e2
* Mon May  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0fb5c4d1c5d39d8e84592117ecfd52f0711d5759
* Fri May  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9f61d1f75ea649e367a17986417329c002544dc7
* Thu May  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e2f543eed7c102b0a6de5138f6dad0a391983d20
* Mon Apr 30 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 558312327ed1d117e049831b69553cac37533a8f
* Fri Apr 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1ce7f1b560e5eee67a01bbb169c720b1ce7de1ea
* Thu Apr 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a877979351a6a149087ef58a7cebb9b08c1b46a8
* Tue Apr 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision f312ed5245cf8f88beb973cee3666889e8f75ffb
* Mon Apr 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d61fc43dd6558593d44128ffd2cccc123c62e426
* Fri Apr 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d07c71e2c8a1a05396a0a69ec23d21d672c6b31c
* Thu Apr 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 071aa2393ee2f05fcaeabefeb392334488be07b5
* Tue Apr 17 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ef99ed684d407475fbf88b44126e7bdcdbdb85b3
* Mon Apr 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 4d99753b0bfa3b846aaf1317f1579012db049936
* Fri Apr 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5684d2f5bd5f8d1a873001f83d02c521870ac87c
* Thu Apr 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7e30178c333856c0deea0e1733edfed76b53f189
* Tue Apr 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ee20121b02e9fb471a76e652c38fb17489dddc98
* Tue Apr 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1f99cfed89fbb401115053cc929a8057178abe0d
* Fri Apr  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1353c009ed7b757fde39e021b4d145751857cee7
* Thu Apr  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 78b7d06b6e3bc316e3d9cd3032d715a31acf0792
* Tue Apr  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7e6d904285f6ef6f09510378ba872b3066949193
* Mon Apr  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 050ce74b800386b4089158dc487f54422f74b2aa
* Thu Mar 29 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e6bfb4a455d940e1c80cb5516b5225d7d4869e8e
* Wed Mar 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3d66afe2fa0c7381a3e598239aa84c964defe6aa
* Tue Mar 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fd62f40fc72159c3113fa998c6909ca0ab5cf4e0
* Mon Mar 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1a6aed8f82cfac11b9551d1e1730146c91a194a1
* Mon Mar 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 98081d6cc977b64f8c1ae029f17b8d93e44fb9fa
* Sat Mar 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 72a4517332fa5ae6f018cb443d4599fc8634fa7f
* Fri Mar 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 191226637bb1df29d748104912aa790381cec2c3
* Wed Mar 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 57722a93ff44ea7ef25fadf2a312896b0c9ea33b
* Mon Mar 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 00aff47bb35af5b31e1f54a320ad2c3389654866
* Fri Mar  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b41c54bb8b77e9f35e4e81cd7fea7b77feef821d
* Thu Mar  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8987ce694118de325a807f69c23b7f3fc830e694
* Mon Mar  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 78da6118be448c4cf515492be75f28f1d235e49b
* Mon Mar  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d584989cb9aa5e1986d598fc222b054f5344dc2b
* Thu Mar  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8c90f6593c8758c3e6f80f855408f1e7571c8e13
* Tue Feb 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a49ec8e1f5718af540c265622fa8b720d4b60853
* Mon Feb 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 216c182936e78a2af630ab4ec141f78011481cf8
* Fri Feb 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ec12d1506f5a7c0298294759c51d9d270b7dedf6
* Thu Feb 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7858bf51db2a7928f831f4a7a8e77754098aedcf
* Wed Feb 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ba8d0a67edc3959eb5599761cd6a0dc1aa01d97e
* Tue Feb 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e8b338324c39358fa1cec2c98812bada6a9e6988
* Sat Feb 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 56e39208042101e36c6666143726ff88b799e2b5
* Fri Feb 17 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 065f76b0c609b4d68edef729f047e4f41ba11d21
* Thu Feb 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8b432310db485749cdd23636f8812e1404326f89
* Mon Feb 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d0d4710e2d432e02f47cda11f597aef13901e274
* Mon Feb 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 682eaec9b722c16dff1edc615a0d4f4b612bec75
* Thu Feb  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 19de310b018b1bf9a120c837dbee6efb2093a3d9
* Tue Feb  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 272ec015f047b386a0a93966128baea9f040db93
* Sat Feb  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ce78c254487ca28b51f7b767bfd4820c9f84290f
* Wed Jan 25 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 14adce34b388440a0483c53f35b89c32db604139
* Sun Jan 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 05f4d5f39ec1569e1e6aa51639ee926681c0f843
* Fri Jan 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cec783f6e06a38ad25aa7f7310a3e8cbf59d02be
* Wed Jan 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 83bf53cab5a156ac1b40427f68a1506cd6ca82ca
* Fri Jan 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b932e5aa03a86abb24c31eb389e4ff9436ea1234
* Tue Jan 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2bdecdc5e4d26a68b36ad3c4daf3e4818d8acf14
* Mon Jan  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5820d67afd8d9fd0c6d502d155ddcf45874add21
* Fri Jan  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e00387216989fb3fd63dbbd5f14882c741b7fbfb
* Wed Jan  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7166a34de507a29ca0d4d853e2f0383d5d845409
* Tue Jan  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cd1e5c3379a87205421acf24e615dd4b292ccbc2
* Sat Dec 31 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1e2044ca13191360645dca2bed8ee2f3e0dd0745
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Wed Dec 28 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision d62a5898184ebd61a6c3d2169818952ab9c46af2
* Wed Dec 28 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7ae0e57307dd67f934212fa21f606def75da776d
* Tue Dec 27 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision e229f78928e8c451671430bb399893b4f57c3915
* Fri Dec 23 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision e14fd1f91c629d7d6c0281df01f710c3b196e5eb
* Thu Dec 22 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 94600afba816259cf6de3ea1e72b9ad3adc13c2a
* Wed Dec 21 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision dead1d198131e5b7e1106528a15ace6700de360d
* Tue Dec 20 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 02b69357cd3a14e0d22eaea670543fde8ae239d8
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 308317c8c95ecd70b82b8ba1464773107def344e
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 71e8ca565b6d09a91efea33119da6237ba941a47
* Mon Dec 12 2011 sleep_walker@suse.cz
- ecore_test is no longer built - remove from ecore-devel
* Mon Dec 12 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 99ddf39a334a67c79449823cd94372c52f2a21be
* Sat Dec 10 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 40ebd546fdf4c2971f59f645e4f374ae35589a67
* Tue Nov 15 2011 tcech@suse.com
- bump version to 1.0.999.65256
* Mon Nov 14 2011 tcech@suse.com
- bump version to 1.0.999.65169
* Sat Nov  5 2011 tcech@suse.com
- bump version to 1.0.999.64752
* Sat Oct 29 2011 tcech@suse.com
- bump version to 1.0.999.64511
* Mon Oct 24 2011 tcech@suse.com
- bump version to 1.0.999.64355
* Sat Oct 22 2011 tcech@suse.com
- refresh ecore-fix-xk.patch
* Fri Oct 21 2011 tcech@suse.com
- bump version to 1.0.999.64279
* Fri Oct 21 2011 tcech@suse.com
- disable Xcomposite for SLES10
* Tue Oct 18 2011 jreidinger@suse.com
- bump version to 1.0.999.64145
* Mon Oct 17 2011 tcech@suse.com
- fix CentOS 5 and SLES10 builds
* Mon Oct 17 2011 tcech@suse.com
- add gettext-devel into buildrequires
* Sun Oct 16 2011 tcech@suse.com
- add autoreconf before configure
* Sun Oct 16 2011 tcech@suse.com
- bump version to 1.0.999.64119
* Sat Oct 15 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Sat Oct 15 2011 tcech@suse.com
- explicitly say that devel package requires evas-devel
* Sat Oct 15 2011 tcech@suse.com
- explicitly say that devel package requires libcurl-devel
* Fri Oct 14 2011 tcech@suse.com
- add xorg-x11-libXdmcp-devel as dependency, explicitly say that
  devel package requires glib2-devel
* Fri Oct 14 2011 jreidinger@suse.com
- bump version to 1.0.999.64070
* Thu Oct 13 2011 jreidinger@suse.com
- bump version to 1.0.999.64049
* Wed Oct 12 2011 tcech@suse.com
- bump version to 1.0.999.64026
* Tue Oct 11 2011 jreidinger@suse.com
- bump version to 1.0.999.63983
* Mon Oct 10 2011 jreidinger@suse.com
- bump version to 1.0.999.63939
* Fri Oct  7 2011 tcech@suse.com
- add eet-devel into dependencies (can fix SLE_11_SP1 error) and
  usefull anyway
* Fri Oct  7 2011 jreidinger@suse.com
- bump version to 1.0.999.63912
* Thu Oct  6 2011 jreidinger@suse.com
- bump version to 1.0.999.63877
* Wed Oct  5 2011 tcech@suse.com
- add SDL as dependency
* Wed Oct  5 2011 jreidinger@suse.com
- bump version to 1.0.999.63840
* Wed Oct  5 2011 jreidinger@suse.com
- bump version to 1.0.999.0
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 1.0.999.63809
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 1.0.999.0
* Mon Oct  3 2011 jreidinger@suse.com
- spec file cleanup
- add glib, openssl and curl support
* Mon Oct  3 2011 jreidinger@suse.com
- bump version to 1.0.999.0
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Fri Sep 30 2011 jreidinger@suse.com
- bump version
* Tue Sep 27 2011 tcech@suse.com
- updated to 1.0.1
- forward-ported jmatejek's patch
- make it buildable for most RPM distros supported by OBS
* Tue Sep 27 2011 jmatejek@suse.com
- fixed build on SLE10 where XK_MISCELLANY is not defined by default
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package for ecore, version 1.0.0
